# Py-CRTSH

Licensed under 3 Clause BSD<br />
This module provides a method to do basic queries to the site, 
[crt.sh](https://crt.sh).

Usage is very basic:

```python
from crtsh import Crtsh
query = Crtsh()
results = query.identify('test.com')
```

More advanced usage may be added as needed/requested
